@@ -349,12 +349,15 @@ class CreateKeyRequest(AbstractModel):
         :type Type: int
         :param Tags: 标签列表
         :type Tags: list of Tag
+        :param HsmClusterId: KMS 高级版对应的 HSM 集群 ID（仅对 KMS 独占版/托管版服务实例有效）。
+        :type HsmClusterId: str
         """
         self.Alias = None
         self.Description = None
         self.KeyUsage = None
         self.Type = None
         self.Tags = None
+        self.HsmClusterId = None
 
 
     def _deserialize(self, params):
@@ -368,6 +371,7 @@ class CreateKeyRequest(AbstractModel):
                 obj = Tag()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        self.HsmClusterId = params.get("HsmClusterId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -403,6 +407,9 @@ class CreateKeyResponse(AbstractModel):
         :param TagMsg: 标签操作的返回信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type TagMsg: str
+        :param HsmClusterId: HSM 集群 ID（仅对 KMS 独占版/托管版服务实例有效）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type HsmClusterId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -414,6 +421,7 @@ class CreateKeyResponse(AbstractModel):
         self.KeyUsage = None
         self.TagCode = None
         self.TagMsg = None
+        self.HsmClusterId = None
         self.RequestId = None
 
 
@@ -426,6 +434,7 @@ class CreateKeyResponse(AbstractModel):
         self.KeyUsage = params.get("KeyUsage")
         self.TagCode = params.get("TagCode")
         self.TagMsg = params.get("TagMsg")
+        self.HsmClusterId = params.get("HsmClusterId")
         self.RequestId = params.get("RequestId")
 
 
@@ -895,9 +904,9 @@ class DescribeWhiteBoxKeyDetailsResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param KeyInfos: 白盒密钥信息列表
+        :param KeyInfos: 白盒密钥信息列表。
         :type KeyInfos: list of WhiteboxKeyInfo
-        :param TotalCount: key总数量
+        :param TotalCount: 白盒密钥总数。
 注意：此字段可能返回 null，表示取不到有效值。
         :type TotalCount: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1277,12 +1286,16 @@ class EnableKeyRotationRequest(AbstractModel):
         r"""
         :param KeyId: CMK唯一标识符
         :type KeyId: str
+        :param RotateDays: 密钥轮转周期，单位天，允许范围 7 ~ 365，默认值 365。
+        :type RotateDays: int
         """
         self.KeyId = None
+        self.RotateDays = None
 
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        self.RotateDays = params.get("RotateDays")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1876,7 +1889,7 @@ class GetServiceStatusResponse(AbstractModel):
         :type InvalidType: int
         :param UserLevel: 0-普通版，1-旗舰版
         :type UserLevel: int
-        :param ProExpireTime: 旗舰版到期时间
+        :param ProExpireTime: 旗舰版到期时间（Epoch Unix Timestamp）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type ProExpireTime: int
         :param ProRenewFlag: 旗舰版是否自动续费：0-不自动续费，1-自动续费
@@ -1885,6 +1898,12 @@ class GetServiceStatusResponse(AbstractModel):
         :param ProResourceId: 旗舰版购买记录的唯一性标识。如果为开通旗舰版，则返回值为空
 注意：此字段可能返回 null，表示取不到有效值。
         :type ProResourceId: str
+        :param ExclusiveVSMEnabled: 是否开通 KMS 托管版
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExclusiveVSMEnabled: bool
+        :param ExclusiveHSMEnabled: 是否开通 KMS 独享版
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExclusiveHSMEnabled: bool
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1894,6 +1913,8 @@ class GetServiceStatusResponse(AbstractModel):
         self.ProExpireTime = None
         self.ProRenewFlag = None
         self.ProResourceId = None
+        self.ExclusiveVSMEnabled = None
+        self.ExclusiveHSMEnabled = None
         self.RequestId = None
 
 
@@ -1904,6 +1925,8 @@ class GetServiceStatusResponse(AbstractModel):
         self.ProExpireTime = params.get("ProExpireTime")
         self.ProRenewFlag = params.get("ProRenewFlag")
         self.ProResourceId = params.get("ProResourceId")
+        self.ExclusiveVSMEnabled = params.get("ExclusiveVSMEnabled")
+        self.ExclusiveHSMEnabled = params.get("ExclusiveHSMEnabled")
         self.RequestId = params.get("RequestId")
 
 
@@ -2024,6 +2047,9 @@ class KeyMetadata(AbstractModel):
         :type ValidTo: int
         :param ResourceId: 资源ID，格式：creatorUin/$creatorUin/$keyId
         :type ResourceId: str
+        :param HsmClusterId: HSM 集群 ID（仅对 KMS 独占版/托管版服务实例有效）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type HsmClusterId: str
         """
         self.KeyId = None
         self.Alias = None
@@ -2040,6 +2066,7 @@ class KeyMetadata(AbstractModel):
         self.Origin = None
         self.ValidTo = None
         self.ResourceId = None
+        self.HsmClusterId = None
 
 
     def _deserialize(self, params):
@@ -2058,6 +2085,7 @@ class KeyMetadata(AbstractModel):
         self.Origin = params.get("Origin")
         self.ValidTo = params.get("ValidTo")
         self.ResourceId = params.get("ResourceId")
+        self.HsmClusterId = params.get("HsmClusterId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2142,6 +2170,8 @@ class ListKeyDetailRequest(AbstractModel):
         :type KeyUsage: str
         :param TagFilters: 标签过滤条件
         :type TagFilters: list of TagFilter
+        :param HsmClusterId: KMS 高级版对应的 HSM 集群 ID（仅对 KMS 独占版/托管版服务实例有效）。
+        :type HsmClusterId: str
         """
         self.Offset = None
         self.Limit = None
@@ -2152,6 +2182,7 @@ class ListKeyDetailRequest(AbstractModel):
         self.Origin = None
         self.KeyUsage = None
         self.TagFilters = None
+        self.HsmClusterId = None
 
 
     def _deserialize(self, params):
@@ -2169,6 +2200,7 @@ class ListKeyDetailRequest(AbstractModel):
                 obj = TagFilter()
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
+        self.HsmClusterId = params.get("HsmClusterId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2222,16 +2254,20 @@ class ListKeysRequest(AbstractModel):
         :type Limit: int
         :param Role: 根据创建者角色筛选，默认 0 表示用户自己创建的cmk， 1 表示授权其它云产品自动创建的cmk
         :type Role: int
+        :param HsmClusterId: KMS 高级版对应的 HSM 集群 ID（仅对 KMS 独占版/托管版服务实例有效）。
+        :type HsmClusterId: str
         """
         self.Offset = None
         self.Limit = None
         self.Role = None
+        self.HsmClusterId = None
 
 
     def _deserialize(self, params):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         self.Role = params.get("Role")
+        self.HsmClusterId = params.get("HsmClusterId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
